summaryrefslogtreecommitdiff
path: root/lib/VNDB/DB/Producers.pm
diff options
context:
space:
mode:
authorYorhel <git@yorhel.nl>2016-11-03 18:08:58 +0100
committerYorhel <git@yorhel.nl>2016-11-03 18:22:43 +0100
commit1e4cdeaca180bdfee0c552c57fccff8570856efd (patch)
tree79ff0dfffaa927cd4217f2640776608af1f7fa33 /lib/VNDB/DB/Producers.pm
parent950b474269ded69504f19c78fa4fea69f0baf7e4 (diff)
Add duplicate check to producer entry
Diffstat (limited to 'lib/VNDB/DB/Producers.pm')
-rw-r--r--lib/VNDB/DB/Producers.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/VNDB/DB/Producers.pm b/lib/VNDB/DB/Producers.pm
index 133c3f31..a6a301e5 100644
--- a/lib/VNDB/DB/Producers.pm
+++ b/lib/VNDB/DB/Producers.pm
@@ -8,7 +8,7 @@ use Exporter 'import';
our @EXPORT = qw|dbProducerGet dbProducerGetRev dbProducerRevisionInsert|;
# options: results, page, id, search, char, sort
# what: extended relations relgraph
sub dbProducerGet {
my $self = shift;
@@ -22,7 +22,7 @@ sub dbProducerGet {
$o{search} =~ s/%//g if $o{search};
my %where = (
- !$o{id} ? (
+ !$o{id} && !$o{inc_hidden} ? (
'p.hidden = FALSE' => 1 ) : (),
$o{id} ? (
'p.id IN(!l)' => [ ref $o{id} ? $o{id} : [$o{id}] ] ) : (),
@@ -8,7 +8,7 @@ use Exporter 'import';
our @EXPORT = qw|dbProducerGet dbProducerGetRev dbProducerRevisionInsert|;
-# options: results, page, id, search, char, sort
+# options: results, page, id, search, char, sort, inc_hidden
# what: extended relations relgraph
sub dbProducerGet {